@@ -152,7 +152,7 @@ def Translate(text, langCombo):
                 'lang': langCombo,
                 'text': text
                 },
-            timeout = 1
+            timeout = 0.6
         )
     except requests.Timeout:
         PrYellow('A request timed out!')
@@ -197,12 +197,8 @@ def RepoCheck():
                 sourceDir = list(filter(lambda x: x[:3] == sourceLang + '_', os.listdir()))[0]
     else:
         sourceDir = sourceLang
-    if sourceDir not in os.listdir():
-        exit()
-
     for lang in targetLangs:
         targetPaths.append('_'.join(lang.split('-')).lower())
-
     try:
         repo = Repo()
     except:
@@ -220,7 +216,7 @@ def RepoCheck():
 
     allModified = modifiedStaged + modifiedUnstaged
     untrackedSrc = [n for n in repo.untracked_files if n.split('/')[0] == sourceDir]
-    return [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + untrackedSrc
+    return [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == sourceDir] + untrackedSrc
 
 #--------------------------------
 
